rm (list=ls())

lplotfile    = FALSE
season       = 'JFM'
iyst         = 1950
year.break   = 1977

dir.Rlib  = '/Users/delsole/SMCS_function_exercises/'
dir.data  = '/Users/delsole/SMCS_data/'

#########################################
## CHECK IF DATA DIRECTORY EXISTS.  IF NOT, SEND ERROR MESSAGE
#########################################
if (!dir.exists(dir.data)) {
	print('#### DATA DIRECTORY DOES NOT EXIST ON YOUR SYSTEM #################')
	print('#### CHANGE dir.data TO THE DIRECTORY CONTAINING YOUR DATA FILES')
	print('#### IF DATA IS IN THE SAME DIRECTORY AS THIS CODE (not recommended), SET dir.data = NULL')
	stop()	
}

#########################################
## IMPORT DATA
#########################################
iyst.read    = 1900
iynd.read    = 2017
nyrs.read    = iynd.read - iyst.read + 1
fdata        = paste(dir.data,'PDO.latest.txt',sep='')
header.pdo   = scan(fdata,what='character()',skip=30,nlines=1,quiet=TRUE)
index.pdo    = read.table(fdata,col.names=header.pdo,skip=32,nrows=nyrs.read)
if (index.pdo[1,1] != iyst.read) stop('first year is not 1900, as expected')
index.pdo[,1] = iyst.read:iynd.read

#########################################
## DEFINE METADATA
#########################################
if ( season == 'JFM') npic.season = 1:3

#########################################
## COMPUTE SEASONAL MEANS
#########################################
pdo   = rowMeans(index.pdo[,npic.season+1])

#########################################
## SPECIFY YEAR
#########################################
year  = index.pdo[,1]


#################################################
## PLOT PDO TIME SERIES
#################################################
fout = paste('pdo',season,'timeseries.eps',sep='.')
if (lplotfile) postscript(fout,horizontal=FALSE,onefile=FALSE,height=5,width=8,pointsize=12)
par(mfcol=c(1,1),mar=c(5,5,4,3))
par(cex.lab=1.5,cex.axis=1.5,cex.main=1.5)
plot(year,pdo,type='b',pch=19,lwd=2,xlab="year",ylab="JFM PDO Index",xlim=c(iyst,iynd.read))
title(main=paste(season,'Average PDO Index'))
abline(h=0)
if (lplotfile) dev.off()


#################################################
### SPLIT DATA INTO TWO PARTS
#################################################
nbreak = which( year == 1977)
pdo1 = pdo[year >= iyst & year <= year.break]
pdo2 = pdo[year > year.break]


#################################################
## TEST EQUALITY OF VARIANCE
#################################################
source(paste(dir.Rlib,'var.equal.test.R',sep=""))
print(var.equal.test(pdo1,pdo2))

