#####################################################################
### THIS R-CODE READS SST DATA ERSST V4 FILES
### THE DATA WAS DOWNLOADED FROM http://www.esrl.noaa.gov/psd/data/gridded/data.noaa.ersst.html
#####################################################################
rm (list=ls())
options(width=70)

lplotfile = FALSE

#####################################################################
### SPECIFY BASIC PARAMETERS FOR READING DATA   #####################
#####################################################################
month    = 'DEC'
iyst     = 1960
iynd     = 2015

dir.data = '/Users/delsole/SMCS_data/'
dir.Rlib = '/Users/delsole/SMCS_function_exercises/'
library(ncdf4) ## to read NetCDF
library(fields)
library(maps)
library(rworldmap)
library(chron)
source(paste(dir.Rlib,'plot_latlon_v4.R',sep=""))
source(paste(dir.Rlib,"pdf.eps.R",sep=""))

amon = c('JAN','FEB','MAR','APR','MAY','JUN','JUL','AUG','SEP','OCT','NOV','DEC')

#####################################################################
### SPECIFY DERIVED QUANTITIES
#####################################################################
mon.say = which(month == amon)
if ( mon.say <= 9 ) mon.say = paste('0',mon.say,sep='') 

nyrs = iynd - iyst + 1

####################################################################################
######################### READ METADATA
####################################################################################
fname = paste(dir.data,'sst.mnmean.v4.nc',sep='')
obs.data = nc_open(fname)	
lon      = ncvar_get(obs.data,varid='lon')
lat      = ncvar_get(obs.data,varid='lat')
time.nc  = ncvar_get(obs.data,varid='time')
nlon     = length(lon)
nlat     = length(lat)
ntime    = length(time.nc)

####################################################################################
######################### SET CLOCK
####################################################################################
time.units = obs.data$var$sst$dim[[3]]$units
time.units = strsplit(time.units,split=' ')[[1]]
if ( time.units[1] != 'days' & time.units[2] != 'since') stop('time units are not based on days')

init.split = strsplit(time.units[3],'-')[[1]]

iyst.units = as.numeric(init.split[1])
imst.units = as.numeric(init.split[2])

time.say   = chron(time.nc,origin=c(month=imst.units,day=1,year=iyst.units),format='m/year')
iyst.raw   = as.numeric(format(as.Date(time.say[1]),'%Y'))
imst.raw   = as.numeric(format(as.Date(time.say[1]),'%m'))
iynd.raw   = as.numeric(format(as.Date(time.say[length(time.say)]),'%Y'))

####################################################################################
######################### READ DATA
####################################################################################
varbl.ncdata   = ncvar_get(obs.data,varid='sst')
nc_close(obs.data)

####################################################################################
######################### REVERSE LATITUDES
####################################################################################
y.rev = nlat:1
lat = lat[y.rev]
dim(varbl.ncdata) = c(nlon,nlat,ntime)
varbl.ncdata      = varbl.ncdata[,y.rev,]

####################################################################################
######################### SET NEGATIVE VALUES TO NA
####################################################################################
varbl.ncdata[varbl.ncdata<0] = NA

####################################################################################
######################### SELECT THE DESIRED MONTH AND YEARS
####################################################################################
month.all = numeric(ntime)
year.all  = numeric(ntime)
month.all[1] = imst.raw
year.all[1]  = iyst.raw
for ( n in 2:ntime) {
	month.all[n] = month.all[n-1] + 1
	year.all[n]  = year.all[n-1]
	if ( month.all[n] > 12) {
		month.all[n] = 1
		year.all[n] = year.all[n] + 1
	}
}
sst = varbl.ncdata[,, month.all == mon.say & year.all >= iyst & year.all <= iynd ]

#####################################################################
############### PLOT SST IN A RANDOM YEAR
#####################################################################
year.pic = 1983
par(mfcol=c(1,1))
par(mar=c(10,3,3,0.5))
plot_latlon_v4(lon,lat,sst[,,year.pic-iyst+1])
title(main=paste('SST from ERSSTv4 in',month,year.pic))

#####################################################################
#####################################################################
#####################################################################
#####################################################################

