rm (list=ls())

lplotfile = FALSE 		# = TRUE PLOT HARDCOPY FIGURES; = FALSE TO PLOT TO SCREEN
season    = 'DJF' 		# SELECT A 3-MONTH SEASON TO STUDY (CAPITAL LETTERS)
neof      = 40			# MAXIMUM NUMBER OF EOFS TO STORE
npoly     = 1			# MAXIMUM ORDER POLYNOMIAL (IN TIME) TO REMOVE FROM DATA
iyst      = 1982		# INITIAL YEAR OF THE ANALYSIS PERIOD
alpha     = 0.05		# SIGNIFICANCE LEVEL
fdr       = 0.1			# FALSE DISCOVERY RATE

### LOAD AUXILARY PROGRAMS AND LIBRARIES
dir.data = '/Users/delsole/SMCS_data/'
dir.Rlib = "/Users/delsole/SMCS_function_exercises/"

source(paste(dir.Rlib,"eof.latlon.R",sep=""))
source(paste(dir.Rlib,"plot_latlon_v4.R",sep=""))
source(paste(dir.Rlib,"pdf.eps.R",sep=""))
source(paste(dir.Rlib,"gev.R",sep=""))
source(paste(dir.Rlib,"enso.index.v2.R",sep=""))
source(paste(dir.Rlib,"index.climate.v2.R",sep=""))

library(fields)
library(maps)
library(rworldmap)

###########################################################################
############################# READ DATA ###################################
###########################################################################
fname = paste(dir.data,'cca.data.clim763.',season,'.RData',sep='')
load(fname)
sst.data   = cca.data.list$sst.data
tem.data   = cca.data.list$varbl.data
lon.sst    = cca.data.list$lon.sst
lon.tem    = cca.data.list$lon.varbl
lat.sst    = cca.data.list$lat.sst
lat.tem    = cca.data.list$lat.varbl
year       = cca.data.list$year
mask.sst   = cca.data.list$mask.sst
mask.tem   = cca.data.list$mask.varbl
print(cca.data.list$comments)

####### DISCARD DATA IF NECESSARY
nypic        = year > iyst
sst.data     = sst.data[,nypic]
tem.data     = tem.data[,nypic]
year         = year    [ nypic]
nyrs         = length(year)
rm(nypic)


############## REMOVE EXRANEOUS VARIABLES TO FREE UP MEMORY ##########
rm(cca.data.list)

############## SET DATA OUTSIDE OF DOMAIN TO NA ######################
sst.data[!mask.sst,] = NA
tem.data[!mask.tem,] = NA

# ############## REMOVE CLIMATOLOGIES ##########
# sst.data = sst.data - rowMeans(sst.data) 
# tem.data = tem.data - rowMeans(tem.data)

##################################
######### REMOVE SST CLIMATOLOGY AND DETREND FOR EACH MONTH
##################################
x = 1:nyrs
x = x - mean(x)
x = x/max(abs(x))
xmat = rep(1,nyrs)
if (npoly >= 1) for (np in 1:npoly) xmat = cbind(xmat,x^np)
x.svd    = svd(xmat)
sst.data = sst.data - (sst.data %*% x.svd$u) %*% t(x.svd$u)
tem.data = tem.data - (tem.data %*% x.svd$u) %*% t(x.svd$u)

plot_latlon_v4(lon.sst,lat.sst,sst.data[,1])
plot_latlon_v4(lon.tem,lat.tem,tem.data[,2])


############## COMPUTE PRINCIPAL COMPONENTS ##########################
tem.eof = eof.latlon(lon.tem,lat.tem,tem.data,idate=c(1,"DJF",year[1],"1yr"),neof=neof)
sst.eof = eof.latlon(lon.sst,lat.sst,sst.data,idate=c(1,"DJF",year[1],"1yr"),neof=neof)


fout = paste('eofs',season,sep='.')
if (lplotfile) pdf.eps(fout,'pdf',width=8.5,height=5)
par(mfrow=c(2,2))
plot_latlon_v4(lon.sst,lat.sst,sst.eof$eof[,1],shrinkdomain=TRUE,title.say='EOF1 of SST')
plot_latlon_v4(lon.tem,lat.tem,tem.eof$eof[,1],shrinkdomain=TRUE,title.say='EOF1 of US Temperature')
plot(year,sst.eof$pc[,1],type='l',main='PC1 of SST')
plot(year,tem.eof$pc[,1],type='l',main='PC1 of US Temp')
if (lplotfile) dev.off()

print(paste('number of SST grid points=',sum(!is.na(sst.eof$eof[,1]))))
print(paste('number of US temperature grid points=',sum(!is.na(tem.eof$eof[,1]))))

nino34 = index.climate.v2(lon.sst,lat.sst,sst.data,area.name='NINO34')$index


####################################################################################
### AT THIS POINT, THIS CODE HAS LOADED THE DATA, SUBSETTED IT PROPERLY, 
### AND DERIVE A FEW THINGS FROM THE DATA.  THE KEY DATA ARE:
### SST.EOF:LIST (EOFS,PCS)
### TEM.EOF:LIST (EOFS,PCS)
### LON.SST[NLON.SST]: LONGITUDES FOR SST DATA
### LAT.SST[NLAT.SST]: LATITUDES FOR SST DATA
### LON.TEM[NLON.TEM]: LONGITUDES FOR U.S. TEMPERATURE DATA
### LAT.TEM[NLAT.TEM]: LATITUDES FOR U.S. TEMPERATURE DATA
### YEAR[NYRS]: YEARS FOR WHICH DATA IS AVAILABLE
### NINO34[NYRS]: ENSO INDEX COMPUTED FROM SST DATA
####################################################################################
### NOW YOU ARE READY TO DO ACTUAL COMPUTATIONS.  
####################################################################################
####################################################################################
####################################################################################
####################################################################################
####################################################################################

