rm(list=ls())

lplotfile      = FALSE	# SET TO 'TRUE' TO GENERATE PDFS, SET TO 'FALSE' TO PRINT TO SCREEN
mon.init       = 6		# CALENDAR MONTH OF THE INITIAL CONDITION (E.G., 6 = JUNE)
mon.targ       = 12		# CALENDAR MONTH OF THE TARGET (E.G., 12 = DECEMBER)

iyst           = 1950
iynd           = 2018
npoly          = 1
domain         = 'PACIFIC30S60N'
neof           = 50

nyrs           = iynd - iyst + 1
year.all       = iyst:iynd
year.valid     = c(1981,1982,1988)
year.train     = setdiff(year.all,year.valid)


########################################
### UNNECESSARY IN STUDENT VERSION
########################################
leave.data.out = FALSE
ntrun          = 34		# UPPER LIMIT TO THE NUMBER OF EOFS
alpha          = 0.05
if (leave.data.out) leave.say = '.pred.ind' else leave.say = '.pred.dep'
prefix         = paste(month.abb[mon.init],'2',month.abb[mon.targ],leave.say,sep='')
options(width=65)
########################################

dir.Rlib       = '/Users/delsole/SMCS_function_exercises/'
dir.data       = '/Users/delsole/SMCS_data/'

if (!dir.exists(dir.data)) {
	print('#### DATA DIRECTORY DOES NOT EXIST ON YOUR SYSTEM #################')
	print('#### CHANGE dir.data TO THE DIRECTORY CONTAINING YOUR DATA FILES')
	print('#### IF DATA IS IN THE SAME DIRECTORY AS THIS CODE (not recommended), SET dir.data = NULL')
	stop()	
}
if (!dir.exists(dir.Rlib)) {
	print('#### DATA DIRECTORY DOES NOT EXIST ON YOUR SYSTEM #################')
	print('#### CHANGE dir.Rlib TO THE DIRECTORY CONTAINING YOUR DATA FILES')
	print('#### IF DATA IS IN THE SAME DIRECTORY AS THIS CODE, SET dir.Rlib = NULL')
	stop()	
}


library(base)
library(fields)
library(ncdf4)
library(maps)
library(fields)
library(rworldmap)

source(paste(dir.Rlib,'plot_latlon_v4.R',sep=''))
source(paste(dir.Rlib,'pdf.eps.R',sep=''))
source(paste(dir.Rlib,'eof.latlon.R',sep=''))
source(paste(dir.Rlib,'mask.define.R',sep=''))

##################################
######### READ METADATA
##################################
filename = paste(dir.data,'/ersstv5/ersst.v5.',iyst,'01.nc',sep='')
ncin     = nc_open(filename)
lon.sst  = ncvar_get(ncin,'lon')
lat.sst  = ncvar_get(ncin,'lat')
nc_close(ncin)

##################################
######### READ DATA
##################################
nlon.sst = length(lon.sst)
nlat.sst = length(lat.sst)
sst.full = array(NA,dim=c(nlon.sst,nlat.sst,12,nyrs))
for ( ny in 1:nyrs) for ( m in 1:12) {
	year = iyst + ny - 1
	if (m < 10) m.say = paste('0',m,sep='') else m.say = as.character(m)
	filename = paste(dir.data,'/ersstv5/ersst.v5.',year,m.say,'.nc',sep='')
	ncin     = nc_open(filename)
	sst.full[,,m,ny]  = ncvar_get(ncin,'sst')
	nc_close(ncin)
}


##################################
######### REMOVE CLIMATOLOGY AND DETREND FOR EACH MONTH
##################################
dim(sst.full) = c(nlon.sst*nlat.sst,12,nyrs)
x = 1:nyrs
x = x - mean(x)
x = x/max(abs(x))
xmat = rep(1,nyrs)
if (npoly >= 1) for (np in 1:npoly) xmat = cbind(xmat,x^np)
x.svd = svd(xmat)
for (m in 1:12) sst.full[,m,] = sst.full[,m,] - (sst.full[,m,] %*% x.svd$u) %*% t(x.svd$u)

##################################
######### DEFINE MASK
##################################
mask.list = mask.define(lon.sst,lat.sst,area.name=domain,ocean=!is.na(sst.full[,1,1]))

##################################
######### PLOT RANDOM MONTH and MASK
##################################
ypic = 1982
mpic = 12
yind = ypic - iyst + 1
par(mfcol=c(3,1))
plot_latlon_v4(lon.sst,lat.sst,sst.full[,mpic,yind],lmaskzero=FALSE)
plot_latlon_v4(lon.sst,lat.sst,mask.list$view,lmaskzero=FALSE)

view = as.logical(mask.list$view)
sst.full[!view,,] = NA
plot_latlon_v4(lon.sst,lat.sst,sst.full[,mpic,yind],lmaskzero=FALSE)

##################################
######### SPECIFY TRAINING AND VALIDATION
##################################
pic.train  = rep(TRUE ,nyrs)
pic.valid  = rep(FALSE,nyrs)
nvalid     = length(year.valid)
for (y in year.valid) pic.train[year.all == y] = FALSE
for (y in year.valid) pic.valid[year.all == y] = TRUE

##################################
######### COMPUTE EOFS
##################################
dim(sst.full) = c(nlon.sst*nlat.sst,12,nyrs)
eof.list      = eof.latlon(lon.sst,lat.sst,sst.full[,,pic.train],neof=neof)

##################################
### COMPUTE PCS BY PROJECTION; NOTE THESE PCS DIFFER FROM EOF.LIST$PC 
### DUE TO (SLIGHTLY) DIFFERENT CLIMATOLOGIES OF FULL V TRAINING DATA
##################################
dim(sst.full) = c(nlon.sst*nlat.sst,12*nyrs)
pc            = t(sst.full[!eof.list$lbad,]) %*%  eof.list$eofi[!eof.list$lbad,]


## CHOOSE THE SIGN TO GIVE POSITIVE AVERAGE SPATIAL PATTERNS
for (n in 1:eof.list$neof) if (sum(eof.list$eof[,n],na.rm=TRUE)<0) {
	eof.list$eof [,n] = -eof.list$eof [,n]
	eof.list$pc  [,n] = -eof.list$pc  [,n]
	eof.list$eofi[,n] = -eof.list$eofi[,n]
	pc           [,n] = -pc[,n]
}

### PLOT LEADING EOF AND PC TIME SERIES
par(mfcol=c(2,1))
time.say = seq(from=iyst,by=1/12,length.out=12*nyrs)
plot_latlon_v4(lon.sst,lat.sst,eof.list$eof[,1],lmaskzero=FALSE,shrinkdomain=TRUE)
plot(time.say,pc[,1],type='l',xlab='year',ylab='PC time series')


##################################
#### AT THIS POINT:
# 		1) THE GRIDDED DATA SET IS IN SST.FULL[SPACE,MONTH,YEAR]
#		2) EOFS ARE IN EOF.LIST (E.G., EOF.LIST$EOF[SPACE,NEOF], EOF.LIST$PC[TIME,NEOF])
# 		3) LAT/LON IS LON.SST, LAT.SST
#		4) MON.INIT AND MON.TARG GIVE THE CALENDAR MONTH OF THE INITAL AND TARGET MONTHS
##################################
##################################
##################################
##################################

