rm (list=ls())

lplotfile = FALSE

varbl    = "tas"
model    = "NCAR.CCSM4"
win      = 'ann'
nens     = 2
alpha    = 0.05
neof     = 50
iyst.20c = 1850

library(ncdf4)
library(fields)
library(maps)
library(rworldmap)

dir.Rlib = "/Users/delsole/SMCS_function_exercises/"
dir.data = "/Users/delsole/SMCS_data/"
source(paste(dir.Rlib,"eof.latlon.R",sep=""))
source(paste(dir.Rlib,"plot_eof_latlon.R",sep=""))
source(paste(dir.Rlib,"plot_latlon_v4.R",sep=""))
source(paste(dir.Rlib,"pdf.eps.R",sep=""))

##################################################################
############### META DATA
##################################################################
if (varbl == 'tas') varbl.say = 'temperature'
if (varbl == 'pr' ) varbl.say = 'precipitation'
if (win   == 'ann') win.say   = 'annual mean'

years.volcano = c(1883, 1902, 1961, 1982, 1991)

##################################
######### READ DATA; COMPUTE ANNUAL MEANS
##################################
filename    = paste(dir.data,'tas_Amon_CCSM4_piControl_r1i1p1_080001-130012.nc',sep='')
print(filename)
ncin        = nc_open(filename)
dat.ctr     = ncvar_get(ncin,'tas')
lon         = ncvar_get(ncin,'lon')
lat         = ncvar_get(ncin,'lat')
nc_close(ncin)

### remove first 200 years
dat.ctr = dat.ctr[,,-(1:(12*200))]
print('cliped first 200 years of control')

nlon = length(lon)
nlat = length(lat)

print('compute annual means')
tdim = dim(dat.ctr)[3]
if (tdim %% 12 != 0 ) stop('control time not a multiple of 12')
tdim.ctr = tdim/12

par(mfcol=c(3,1))
dim(dat.ctr) = c(nlon*nlat,tdim)
dat.ctr.clim = rowMeans(dat.ctr)
plot_latlon_v4(lon,lat,rowMeans(dat.ctr[,1:12])-dat.ctr.clim)

dim(dat.ctr) = c(nlon*nlat,12,tdim.ctr)
dat.ctr      = aperm(dat.ctr,c(1,3,2))
dim(dat.ctr) = c(nlon*nlat*tdim.ctr,12)
dat.ctr      = rowMeans(dat.ctr)
dim(dat.ctr) = c(nlon*nlat,tdim.ctr)

plot_latlon_v4(lon,lat,dat.ctr[,1]-dat.ctr.clim)

for ( ne in 1:nens) {
	filename    = paste(dir.data,'tas_Amon_CCSM4_historical_r',ne,'i1p1_185001-200512.nc',sep='')
	print(filename)
	ncin        = nc_open(filename)
	tas         = ncvar_get(ncin,'tas')
	tdim        = dim(tas)[3]
	if (tdim %% 12 != 0 ) stop('control time not a multiple of 12')
	tdim.20c    = tdim/12
	dim(tas)    = c(nlon*nlat,12,tdim.20c)
	tas         = aperm(tas,c(1,3,2))
	dim(tas)    = c(nlon*nlat*tdim.20c,12)
	tas         = rowMeans(tas)
	if (ne == 1) dat.20c = array(NA,dim=c(nlon*nlat*tdim.20c,nens))
	dat.20c[,ne] = tas
	nc_close(ncin)
}
dim(dat.20c) = c(nlon*nlat,tdim.20c*nens)
dat.20c.clim = rowMeans(dat.20c) 
plot_latlon_v4(lon,lat,dat.20c.clim - dat.ctr.clim)
dim(dat.20c) = c(nlon*nlat,tdim.20c,nens)

################################
######### COMPUTE EOFS
################################
##### META DATA
print('compute eofs')
idate = c(1,'jan',1850,"1yr")
dname = paste(varbl,win,model)
eof.list = eof.latlon(lon,lat,cbind(dat.ctr[,1:tdim.20c]-dat.ctr.clim,dat.20c[,1:tdim.20c,1]-dat.20c.clim),neof=neof,idate=idate,dname=dname)
plot_eof_latlon(eof.list,1)

################################
######### PROJECT EOFS
################################
dim(dat.ctr) = c(nlon*nlat,tdim.ctr)
dim(dat.20c) = c(nlon*nlat,tdim.20c*nens)

pc.20c       = t(dat.20c) %*% eof.list$eofi
pc.ctr       = t(dat.ctr) %*% eof.list$eofi

################################
###### CENTER
################################
pc.20c = t( t(pc.20c) - colMeans(pc.20c))
pc.ctr = t( t(pc.ctr) - colMeans(pc.ctr))

###########################################
######## AT THIS POINT, THE 20C AND PI SIMULATIONS HAVE BEEN READ.
######## A *SINGLE* SET OF EOFS HAVE BEEN COMPUTED, AND
######## THE PROJECTED TIME SERIES IN 20C AND PI SIMULATIONS 
######## HAVE BEEN COMPUTED.
######## THE FOLLOWING DATA IS AVAILABLE FOR ANALYSIS:
######## PC.20C[SPACE,TIME,ENSEMBLE]: PC TIME SERIES FOR 20C RUN
######## PC.CTR[SPACE,TIME]: PC TIME SERIES FOR PI RUN
######## TDIM.20C: TIME DIMENSION OF 20C RUN
######## TDIM.CTR: TIME DIMENSION OF PI RUN
######## NENS: NUMBER OF ENSEMBLE MEMBERS FOR 20C RUN
######## EOF.LIST: OUTPUT FROM EOF CALCULATION (TYPE 'NAMES(EOF.LIST)' TO SEE CONTENT)
###########################################
###########################################
###########################################

