rm(list=ls())

lplotfile = FALSE

#### SET PARAMETERS
varbl    = "tmp2m"
basin    = 'NAMERICA'
icmon    = 'nov'
vfmon    = 'jan'
epic     = 17:24


# dir.data = "/Users/delsole/data/cfsv2rr/"
dir.data = "/Users/delsole/SMCS_data/"
dir.Rlib  = "/Users/delsole/SMCS_function_exercises/"

if (!dir.exists(dir.data)) {
	print('#### DATA DIRECTORY DOES NOT EXIST ON YOUR SYSTEM #################')
	print('#### CHANGE dir.data TO THE DIRECTORY CONTAINING YOUR DATA FILES')
	print('#### IF DATA IS IN THE SAME DIRECTORY AS THIS CODE (not recommended), SET dir.data = NULL')
	stop()	
}
if (!dir.exists(dir.Rlib)) {
	print('#### DATA DIRECTORY DOES NOT EXIST ON YOUR SYSTEM #################')
	print('#### CHANGE dir.Rlib TO THE DIRECTORY CONTAINING YOUR DATA FILES')
	print('#### IF DATA IS IN THE SAME DIRECTORY AS THIS CODE, SET dir.Rlib = NULL')
	stop()	
}


### LOAD LIBRARIES AND FUNCTIONS
library(fields)
library(maps)
library(rworldmap)

source(paste(dir.Rlib,"plot_latlon_v4.R",sep=""))
source(paste(dir.Rlib,"plot_latlon_bw.R",sep=""))
source(paste(dir.Rlib,"index.climate.v2.R",sep=""))
source(paste(dir.Rlib,"interesting.points.R",sep=""))

#### READ METADATA (GRID, TIME STEPS, ETC)
fctl     = paste(dir.data,varbl,'.monthly.',icmon,'IC.',vfmon,'V.cfsv2rr.ctl'  ,sep='')
fdat     = paste(dir.data,varbl,'.monthly.',icmon,'IC.',vfmon,'V.cfsv2rr.grads',sep='')
flat     = paste(dir.data,'lats.cfsv2rr.txt',sep="")

command   = paste("awk '/^xdef/{print $2}' ",fctl,sep="")
lon.tot   = as.numeric(system(command,intern=TRUE))
command   = paste("awk '/^xdef/{print $4}' ",fctl,sep="")
lon.start = as.numeric(system(command,intern=TRUE))
command   = paste("awk '/^xdef/{print $5}' ",fctl,sep="")
lon.by    = as.numeric(system(command,intern=TRUE))
command   = paste("awk '/^tdef/{print $2}' ",fctl,sep="")
tdim      = as.numeric(system(command,intern=TRUE))
command   = paste("awk '/^tdef/{print $4}' ",fctl,sep="")
stdate    = system(command,intern=TRUE)
command   = paste("awk '/^undef/{print $2}' ",fctl,sep="")
undef     = as.numeric(system(command,intern=TRUE))
command   = paste("awk '/^zdef/{print $2}' ",fctl,sep="")
nens      = as.numeric(system(command,intern=TRUE))
command   = paste("awk '/^tdef/{print $2}' ",fctl,sep="")
nyrs      = as.numeric(system(command,intern=TRUE))


### DEFINE METADATA
lon       = seq(from=lon.start,by=lon.by,length.out=lon.tot)
lat       = scan(flat,quiet=TRUE)
nlon      = length(lon)
nlat      = length(lat)
iyst      = as.numeric(substr(stdate,nchar(stdate)-3,nchar(stdate)))
iynd      = iyst + nyrs - 1

icmon.read = substr(stdate,nchar(stdate)-6,nchar(stdate)-4)
if (icmon != icmon.read) stop('read wrong month')

prefix = paste(varbl,basin,icmon,vfmon,sep='.')


### READ LAND MASK
fmask   = paste(dir.data,'landsea.cfsv2rr.grads',sep='')
landsea = as.logical(readBin(fmask,'numeric',n=nlon*nlat,size='4',endian='little'))
par(mfcol=c(1,1),mar=c(9,4,4,1))
plot_latlon_v4(lon,lat,landsea)

### READ DATA
hcst.data = readBin(fdat,'numeric',n=nlon*nlat*tdim*nens,size='4',endian='little')
dim(hcst.data) = c(nlon,nlat,nens,nyrs)
plot_latlon_v4(lon,lat,hcst.data[,,1,1])

#### REMOVE LAST "ENSEMBLE MEMBER", WHICH IS JUST THE ENSEMBLE MEAN
hcst.data = hcst.data[,,epic,]
nens      = length(epic)

### GENERATE DOMAIN MASK
domain.list = index.climate.v2(lon,lat,area.name=basin,ocean=!landsea)
plot_latlon_v4(lon,lat,domain.list$view)

dim(landsea) = c(nlon,nlat)
view         = domain.list$view & landsea

### SUBSET DATA (TO SAVE SPACE)
min.which.function = function(x) if (all(!x)) NA else min(which(x),na.rm=TRUE)
max.which.function = function(x) if (all(!x)) NA else max(which(x),na.rm=TRUE)

lon.min = apply(domain.list$view,2,min.which.function)
lon.min[is.infinite(lon.min)] = NA
lon.min = min(lon.min,na.rm=TRUE)

lon.max = apply(domain.list$view,2,max.which.function)
lon.max[is.infinite(lon.max)] = NA
lon.max = max(lon.max,na.rm=TRUE)

lat.min = apply(domain.list$view,1,min.which.function)
lat.min[is.infinite(lat.min)] = NA
lat.min = min(lat.min,na.rm=TRUE)

lat.max = apply(domain.list$view,1,max.which.function)
lat.max[is.infinite(lat.max)] = NA
lat.max = max(lat.max,na.rm=TRUE)

hcst.data    = hcst.data[lon.min:lon.max,lat.min:lat.max,,]
view         = view[lon.min:lon.max,lat.min:lat.max]

lon          = lon[lon.min:lon.max]
lat          = lat[lat.min:lat.max]
nlon         = length(lon)
nlat         = length(lat)

par(mfcol=c(1,2),mar=c(12,4,4,1))
plot_latlon_v4(lon,lat,view)
plot_latlon_v4(lon,lat,hcst.data[,,1,1])

### INCLUDE ONLY LAND DATA
dim(hcst.data)     = c(nlon*nlat,nens,nyrs)
dim(view)          = nlon*nlat
hcst.data[!view,,] = NA
par(mfcol=c(1,1),mar=c(12,4,4,1))
plot_latlon_v4(lon,lat,hcst.data[,1,1])

######################################################
######################################################
## AT THIS POINT, THE FOLLOWING VARIABLES ARE AVAILABLE:
## VARBL: NAME OF THE VARIABLE (E.G., TEMPERATURE)
## ICMON: INITIAL CONDITION MONTH (E.G., 'NOV')
## VFMON: VERIFICATION MONTH (E.G., 'JAN')
## EPIC: SELECTED ENSEMBLE MEMBERS (E.G., 1,2,...,24)
## NENS: TOTAL NUMBER OF ENSEMBLE MEMBERS (LENGTH(EPIC))
## NYRS: NUMBER OF YEARS
## IYST: FIRST YEAR OF THE DATA SET
## LON[NLON]: LONGITUDE VALUES OF THE DOMAIN
## LAT[NLAT]: LATITUDE VALUES OF THE DOMAIN
## HCST.DATA[NLON,NLAT,NENS,NYRS]: HINDCAST DATA
## VIEW[NLON,NLAT]: N. AMERICAN MASK
## 
######################################################
######################################################
