rm(list=ls())

lplotfile = FALSE


#### SET PARAMETERS
varbl    = "tref"
model    = 'NCEP-CFSv2'
basin    = 'NAMERICA'
icmon    = 'Nov'
iyst     = 1982
iynd     = 2009
lead     = 6
epic     = 17:24
epic     = 9:24
neof     = 30
alpha    = 0.01

dir.data    = '/Users/delsole/SMCS_data/'
dir.Rlib    = "/Users/delsole/SMCS_function_exercises/"
mon.st      = which(icmon == month.abb)
suffix      = paste('_',varbl,'_',model,sep='')
nyrs        = iynd - iyst + 1
nens        = length(epic)

mon.f       = mon.st + lead - 1
if (mon.f > 12) mon.f = mon.f - 12
vfmon       = month.abb[mon.f] 
prefix      = paste(varbl,basin,icmon,vfmon,sep='.')

set.seed(1)

### LOAD LIBRARIES AND FUNCTIONS
library(ncdf4)
library(fields)
library(maps)
library(rworldmap)

source(paste(dir.Rlib,"plot_latlon_v4.R",sep=""))
source(paste(dir.Rlib,"index.climate.v2.R",sep=""))
source(paste(dir.Rlib,"interesting.points.R",sep=""))
source(paste(dir.Rlib,"gev.R",sep=""))
source(paste(dir.Rlib,"eof.latlon.R",sep=""))

source(paste(dir.Rlib,"plot_latlon_bw.R",sep=""))
source(paste(dir.Rlib,"pdf.eps.R",sep=""))
source(paste(dir.Rlib,"enso.index.R",sep=""))
options(width=70)

###############################
######### READ METADATA
###############################
filename = paste(dir.data,'cfsv2/',iyst,mon.st,suffix,'.nc',sep='')
ncin     = nc_open(filename)
lon      = ncvar_get(ncin,'lon')
lat      = ncvar_get(ncin,'lat')
time.nc  = ncvar_get(ncin,'time')
ens.nc   = ncvar_get(ncin,'ens')
nc_close(ncin)

nlon     = length(lon)
nlat     = length(lat)
###############################
######### READ DATA
###############################
hcst.data = array(NA,dim=c(nlon,nlat,nens,nyrs))
for ( ny in 1:nyrs) {
	year     = ny + iyst - 1
	filename = paste(dir.data,'cfsv2/',year,mon.st,suffix,'.nc',sep='')
	print(filename)
	ncin     = nc_open(filename)
	hcst.data[,,,ny]   = ncvar_get(ncin,varbl)[,,lead,epic]
	nc_close(ncin)
}

###############################
######### READ LAND-SEA MASK
###############################
ncin = nc_open(paste(dir.data,'land_cover.nc',sep=''))
land.cover = ncvar_get(ncin,'land')
nc_close(ncin)
plot_latlon_v4(lon,lat,land.cover)

### GENERATE DOMAIN MASK
domain.list = index.climate.v2(lon,lat,area.name=basin,ocean=!land.cover)
plot_latlon_v4(lon,lat,domain.list$view)


dim(land.cover) = c(nlon,nlat)
view            = domain.list$view & land.cover
plot_latlon_v4(lon,lat,view)

### SUBSET DATA (TO SAVE SPACE)
min.which.function = function(x) if (all(!x)) NA else min(which(x),na.rm=TRUE)
max.which.function = function(x) if (all(!x)) NA else max(which(x),na.rm=TRUE)

lon.min = apply(domain.list$view,2,min.which.function)
lon.min[is.infinite(lon.min)] = NA
lon.min = min(lon.min,na.rm=TRUE)

lon.max = apply(domain.list$view,2,max.which.function)
lon.max[is.infinite(lon.max)] = NA
lon.max = max(lon.max,na.rm=TRUE)

lat.min = apply(domain.list$view,1,min.which.function)
lat.min[is.infinite(lat.min)] = NA
lat.min = min(lat.min,na.rm=TRUE)

lat.max = apply(domain.list$view,1,max.which.function)
lat.max[is.infinite(lat.max)] = NA
lat.max = max(lat.max,na.rm=TRUE)

hcst.data    = hcst.data[lon.min:lon.max,lat.min:lat.max,,]
view         = view[lon.min:lon.max,lat.min:lat.max]

lon          = lon[lon.min:lon.max]
lat          = lat[lat.min:lat.max]
nlon         = length(lon)
nlat         = length(lat)

par(mfcol=c(1,2),mar=c(12,4,4,1))
plot_latlon_v4(lon,lat,view)
plot_latlon_v4(lon,lat,hcst.data[,,1,1])

### INCLUDE ONLY LAND DATA
dim(hcst.data)     = c(nlon*nlat,nens,nyrs)
dim(view)          = nlon*nlat
hcst.data[!view,,] = NA
par(mfcol=c(1,1),mar=c(12,4,4,1))
plot_latlon_v4(lon,lat,hcst.data[,1,1])

######################################################
######################################################
## AT THIS POINT, THE FOLLOWING VARIABLES ARE AVAILABLE:
## VARBL: CHARACTER NAME OF THE VARIABLE (E.G., TEMPERATURE)
## ICMON: INITIAL CONDITION MONTH (E.G., 'NOV')
## VFMON: VERIFICATION MONTH (E.G., 'JAN')
## EPIC: SELECTED ENSEMBLE MEMBERS (E.G., 1,2,...,24)
## NENS: TOTAL NUMBER OF ENSEMBLE MEMBERS (LENGTH(EPIC))
## NYRS: NUMBER OF YEARS
## IYST: FIRST YEAR OF THE DATA SET
## LON[NLON]: LONGITUDE VALUES OF THE DOMAIN
## LAT[NLAT]: LATITUDE VALUES OF THE DOMAIN
## HCST.DATA[NLON,NLAT,NENS,NYRS]: HINDCAST DATA
## VIEW[NLON,NLAT]: N. AMERICAN MASK
## 
######################################################
######################################################
