rm(list=ls())

lplotfile = FALSE

ndays.raw = 90
ndays.sub = 31
iyst.raw  = 1950
iynd.raw  = 2015
iyst.sub  = 1970
iynd.sub  = 2015
npoly.d   = 0
npoly.y   = 0
npoly.y.nonstat = 1
domain    = 'mid_atlantic'
index.say = 'NAO'

library(extRemes)

dir.data    = '/Users/delsole/SMCS_data/'
dir.Rlib    = "/Users/delsole/SMCS_function_exercises/"
source(paste(dir.Rlib,"pdf.eps.R",sep=""))
source(paste(dir.Rlib,"tele_index.R",sep=""))

if (!dir.exists(dir.data)) {
	print('#### DATA DIRECTORY DOES NOT EXIST ON YOUR SYSTEM #################')
	print('#### CHANGE dir.indices TO THE DIRECTORY CONTAINING YOUR DATA FILES')
	print('#### IF DATA IS IN THE SAME DIRECTORY AS THIS CODE (not recommended), SET dir.indices = NULL')
	stop()	
}
if (!dir.exists(dir.Rlib)) {
	print('#### DATA DIRECTORY DOES NOT EXIST ON YOUR SYSTEM #################')
	print('#### CHANGE dir.Rlib TO THE DIRECTORY CONTAINING YOUR DATA FILES')
	print('#### IF DATA IS IN THE SAME DIRECTORY AS THIS CODE, SET dir.Rlib = NULL')
	stop()	
}

######################################
########## DEFINE META DATA
######################################
nyrs   = iynd.raw - iyst.raw + 1
ndays  = ndays.raw
ntot   = ndays*nyrs
finput = paste(dir.data,'GHNC_OBS_T_',domain,'_',iyst.raw,'_',iynd.raw,'.txt',sep='')
if ( domain == 'mid_atlantic') {
	location = 'Mid-Atlantic'
} else if ( domain == 'north_atlantic') {
	location = 'North-Atlantic'
} else stop(paste('do not understand domain=',domain))

if ( ndays.sub <= 31) {
	mon.ave = 1
} else if (ndays.sub == 90) {
	mon.ave = c(1,2,3)
}

######################################
########## READ DATA
######################################
data.all = scan(finput,sep=',',quiet=TRUE)

dim(data.all) = c(nyrs,ndays)
data.all      = t(data.all)

######################################
########## SUBSET DATA
######################################
dim(data.all) = c(ndays,nyrs)
nst           = which(iyst.raw:iynd.raw == iyst.sub)
nnd           = which(iyst.raw:iynd.raw == iynd.sub)

data.all      = data.all[1:ndays.sub,nst:nnd]
iyst          = iyst.sub
iynd          = iynd.sub 
nyrs          = iynd - iyst + 1
ndays         = ndays.sub
ntot          = ndays*nyrs
colnames(data.all) = iyst:iynd

######################################
########## IDENTIFY EXTREMES
######################################
t.cold = numeric(nyrs)
t.warm = numeric(nyrs)
for ( n in 1:nyrs) t.cold[n] = min(data.all[,n])
for ( n in 1:nyrs) t.warm[n] = max(data.all[,n])

######################################
########## GET TELECONNECTION INDEX
######################################
tele  = tele_index(iyst,iynd,index.name=index.say,months.to.average=mon.ave)
index = tele - mean(tele)

######################################
########## PLOT DATA
######################################
fout = paste(domain,'time.series',sep='.')
if (lplotfile) pdf.eps(fout,'pdf',width=8,height=4)
par(mfcol=c(1,1),mar=c(5,5,3,1))
par(cex.lab=1.3,cex.axis=1.3,cex.main=1.3)
xrange = c(iyst,iynd)
yrange = range(data.all)
boxplot(data.all,xlim=c(1,nyrs),ylim=yrange,col='grey',whisklty=0,staplelty=0,outline=FALSE,xaxt='n',xlab='year',ylab='degrees C')
n.say  = seq(from=1,to=nyrs,by=10)
y.say  = (iyst:iynd)[n.say]
axis(1,at=n.say,labels=y.say)
abline(v=seq(from=1,to=nyrs,by=5),lty='dotted',col='grey60',lwd=1)
ftitle.top  = paste(domain,'anomalies after removing')
ftitle.bot  = paste(npoly.d,'daily and',npoly.y,'annual polynomials')
ftitle.bot  = paste('January Daily Temperatures over',location,'U.S.')
# title(main=ftitle.top,line=2)
title(main=ftitle.bot,line=0.5)
points(t.cold,pch=19,cex=0.8)
if (lplotfile) dev.off()

