rm(list=ls())

lplotfile = FALSE
lstandard = FALSE
set.seed(2)
ndim      = 3
ntot      = 100
nspin     = 100

dir.Rlib = '/Users/delsole/SMCS_function_exercises/'

if (lstandard) suffix = NULL else suffix = '.ObsSum'

### SPECIFY THE MATRICES
if ( ndim == 3) {
	dynop = matrix(c(0.9,0.5,0.3,0,0.5,2,0,0,0.4),nrow=3,byrow=TRUE)
	
	qdiag = c(0,0,1)
	q.cov = matrix(rep(0,ndim^2),ncol=ndim)
	for ( n in 1:ndim) q.cov[n,n] = qdiag[n]
	
	if (lstandard) {
		# STANDARD CASE
		hop   = matrix(c(1,0,0),ncol=ndim)
		nobs  = dim(hop)[1]
		rdiag = rep(49,nobs)		
	} else {
	 	## OBSERVE SUM OF VARIABLES
	 	hop   = matrix(c(1,1,0),ncol=ndim)
		nobs  = dim(hop)[1]
	 	rdiag = rep(25,nobs)		
	}
 	
	r.cov = matrix(rep(0,nobs^2),ncol=nobs)
	for (n in 1:nobs) r.cov[n,n] = rdiag[n]
		
} else print(paste("no pre-set dynamical operator for ndim=",ndim))

### "SPIN UP" THE DYNAMICAL MODEL
x = matrix(rep(0,ndim*ntot),nrow=ndim)
x[,1] = rep(1,ndim)
{ia = 2; ib = 1}
for ( n in 2:nspin) {
	{idum = ia; ia   = ib; ib   = idum}
	x[,ib] = dynop %*% x[,ia] + rnorm(ndim,sd=sqrt(qdiag))
}

### GENERATE TRUE TIME SERIES
for ( n in 2:ntot) x[,n] = dynop %*% x[,n-1] + rnorm(ndim,sd=sqrt(qdiag))

### GENERATE OBSERVATIONS
obs = hop %*% x + matrix(rnorm(ntot*nobs,sd=sqrt(rdiag)),nrow=nobs,byrow=TRUE)


#####################################################################
### THE FOLLOWING QUANTITES ARE NOW AVAILABLE:
# NDIM:  THE DIMENSION OF THE VECTOR AUTOREGRESSIVE MODEL (VAR); DEFAULT = 3
# NTOT:  THE TOTAL LENGTH OF THE TIME SERIES; DEFAULT = 100
# NOBS:  NUMBER OF OBSERVATIONS PER TIME STEP; DEFAULT = 1
# X:     [NDIM, NTOT] MATRIX SPECIFYING THE "TRUTH" AT EACH TIME STEP
# OBS:   [NOBS, NTOT] MATRIX SPECIFYING THE "OBSERVATIONS" AT EACH TIME STEP
# DYNOP: [NDIM, NDIM] MATRIX SPECIFYING THE DYNAMICAL OPERATOR OF THE VAR
# HOP:   [NOBS, NDIM] MATRIX SPECIFYING THE INTERPOLATION OPERATOR
# Q.COV: [NDIM, NDIM] MATRIX SPECIFYING THE NOISE COVARIANCE MATRIX OF THE VAR
# R.COV: [NOBS, NOBS] MATRIX SPECIFYING THE ERROR COVARIANCE MATRIX OF THE OBS

